@@ -1,4 +1,6 @@
+approve <-
 ApproveAssignment <-
+ApproveAssignments <-
 function (assignments, feedback = NULL, rejected = FALSE, keypair = credentials(), 
     print = FALSE, browser = FALSE, log.requests = TRUE, sandbox = FALSE) 
 {
