@@ -1,4 +1,6 @@
+block <-
 BlockWorker <-
+BlockWorkers <-
 function (workers, reasons, keypair = credentials(), print = TRUE, 
     browser = FALSE, log.requests = TRUE, sandbox = FALSE) 
 {
