@@ -2,19 +2,22 @@ GenerateAnswerKey <-
 function (questions, scoring = NULL) 
 {
     answerkey <- newXMLNode("AnswerKey", namespaceDefinitions = "http://mechanicalturk.amazonaws.com/AWSMechanicalTurkDataSchemas/2005-10-01/AnswerKey.xsd")
-    for (i in 1:dim(questions)[1]) {
+    for (i in 1:length(questions)) {
         question <- newXMLNode("Question", parent = answerkey)
-        id <- newXMLNode("QuestionIdentifier", questions$QuestionIdentifier[i], 
+        id <- newXMLNode("QuestionIdentifier", questions[[i]]$QuestionIdentifier,
             parent = question)
         addChildren(question, id)
-        opt <- newXMLNode("AnswerOption", parent = question)
-        selid <- newXMLNode("SelectionIdentifier", questions$SelectionIdentifier[i], 
-            parent = opt)
-        score <- newXMLNode("AnswerScore", questions$AnswerScore[i], 
-            parent = opt)
-        addChildren(opt, c(selid, score))
-        if (!is.null(questions$DefaultScore[i])) {
-            default <- newXMLNode("DefaultScore", questions$DefaultScore[i], 
+		answeropts <- questions[[i]][!names(questions[[i]]) %in% c("QuestionIdentifier","DefaultScore")]
+		for(j in 1:length(answeropts)){
+			opt <- newXMLNode("AnswerOption", parent = question)
+			selid <- newXMLNode("SelectionIdentifier", answeropts[[j]]$SelectionIdentifier,
+				parent = opt)
+			score <- newXMLNode("AnswerScore", answeropts[[j]]$AnswerScore,
+				parent = opt)
+			addChildren(opt, c(selid, score))
+		}
+        if (!is.null(questions[[i]]$DefaultScore)) {
+            default <- newXMLNode("DefaultScore", questions[[i]]$DefaultScore,
                 parent = question)
             addChildren(question, default)
         }
@@ -63,5 +66,28 @@ function (questions, scoring = NULL)
     }
     string <- toString.XMLNode(answerkey)
     encoded <- curlEscape(string)
-    return(list(xml.parsed = answerkey, string = string, url.encoded = encoded))
+    return(list(xml.parsed = xmlParse(string), string = string, url.encoded = encoded))
+}
+
+AnswerKeyTemplate <-
+function(xml = NULL, xml.parsed = NULL)
+{
+	if (!is.null(xml)) 
+        xml.parsed <- xmlParse(xml)
+    qformdf <- QuestionFormToDataFrame(xml.parsed = xml.parsed)$Questions
+	answerkey <- list(NULL)
+	for(i in 1:dim(qformdf)[1]){
+		answerkey[[i]]$QuestionIdentifier <- qformdf$QuestionIdentifier[i]
+		answerspecification <- xmlChildren(xmlChildren(xmlParse(qformdf$AnswerSpecification[i]))$AnswerSpecification)
+		if(!names(answerspecification)=="SelectionAnswer")
+			stop("Question",answerkey[[i]]$QuestionIdentifier,"is not a SelectionAnswer. AnswerKey cannot be generated.")
+		opts <- xmlChildren(xmlChildren(answerspecification$SelectionAnswer)$Selections)
+		for(j in 1:length(opts)){
+			answerkey[[i]][[j+1]] <- list(
+				Text = xmlValue(xmlChildren(opts[[j]])$Text),
+				SelectionIdentifier = xmlValue(xmlChildren(opts[[j]])$SelectionIdentifier),
+				AnswerScore = NULL ) 
+		}
+	}
+	return(answerkey)
 }
