@@ -1,4 +1,5 @@
 GetQualifications <-
+getquals <-
 function (qual, status = NULL, return.all = TRUE, pagenumber = 1, 
     pagesize = 100, keypair = credentials(), print = TRUE, log.requests = TRUE, 
     sandbox = FALSE, return.qual.dataframe = TRUE) 
@@ -60,11 +61,8 @@ function (qual, status = NULL, return.all = TRUE, pagenumber = 1,
     request$batch.total <- NULL
     if (print == TRUE) {
         cat(request$total, " Qualifications Retrieved\n", sep = "")
-        if (request$total > 0) {
+        if (request$total > 0)
             return(request$Qualifications)
-            print(request$Qualifications)
-            cat("\n")
-        }
     }
     else {
         if (request$total > 0) 
