@@ -1,4 +1,6 @@
 GrantQualification <-
+GrantQualifications <-
+grantqual <-
 function (qual.requests, values, keypair = credentials(), print = TRUE, 
     browser = FALSE, log.requests = TRUE, sandbox = FALSE) 
 {
