@@ -3,10 +3,10 @@ function (xml = NULL, xml.parsed = NULL)
 {
     if (!is.null(xml)) 
         xml.parsed <- xmlParse(xml)
-    qf <- xmlChildren(xmlChildren(xmlParse(qf))$QuestionForm)
-    overview <- qf[names(qf) == "Overview"]
-    questions <- qf[names(qf) == "Question"]
-    ov <- data.frame(matrix(nrow = length(overview), ncol = ))
+    qform <- xmlChildren(xmlChildren(xml.parsed)$QuestionForm)
+    #overview <- qform[names(qform) == "Overview"]
+    questions <- qform[names(qform) == "Question"]
+    #ov <- data.frame(matrix(nrow = length(overview), ncol = ))
     qdf <- data.frame(matrix(nrow = length(questions), ncol = 5))
     names(qdf) <- c("QuestionIdentifier", "DisplayName", "IsRequired", 
         "QuestionContent", "AnswerSpecification")
@@ -17,5 +17,6 @@ function (xml = NULL, xml.parsed = NULL)
         qdf$QuestionContent[i] <- toString.XMLNode(xmlChildren(questions[[i]])$QuestionContent)
         qdf$AnswerSpecification[i] <- toString.XMLNode(xmlChildren(questions[[i]])$AnswerSpecification)
     }
-    return(list(Overview = ov, Questions = qdf))
+    #return(list(Overview = ov, Questions = qdf))
+	return(list(Questions = qdf))
 }
